@@ -102,7 +102,7 @@ class s2py():
             uname = uname['author']['username']
             data = requests.get("https://api.scratch.mit.edu/users/" +
                                 str(uname)+"/projects/"+str(id)+"/comments").json()
-            if data != {"code": "ResourceNotFound", "message": "/users/LT/projects/175/comments does not exist"} and data != {"code": "NotFound", "message": ""}:
+            if data != {"code": "ResourceNotFound", "message": "/users/"+str(uname)+"/projects/175/comments does not exist"} and data != {"code": "NotFound", "message": ""}:
                 comments = []
                 x = ""
                 for i in data:
@@ -117,22 +117,6 @@ class s2py():
         requests.put("https://scratch.mit.edu/site-api/users/curators-in/" +
                      str(sid) + "/invite_curator/?usernames=" + user, headers=self.headers,)
 
-    def postProfileComment(self, user, content, parent_id="", commentee_id=""):
-        self.headers['referer'] = (
-            "https://scratch.mit.edu/users/" + str(user)
-        )
-        data = json.dumps({
-            "commentee_id": commentee_id,
-            "content": content,
-            "parent_id": parent_id,
-        })
-        return requests.post(
-            "https://scratch.mit.edu/site-api/comments/user/"
-            + str(user) + "/add/",
-            headers=self.headers,
-            data=data,
-        )
-    
     def postProjectComment(self, pid, content, parent_id="", commentee_id=""):
         self.headers['referer'] = (
             "https://scratch.mit.edu/projects/" + str(pid)
